@@ -616,7 +616,11 @@ class FeatureGroup(FeatureGroupBase):
             self._partition_key = [
                 feat.name for feat in self._features if feat.partition is True
             ]
-            if time_travel_format is not None and time_travel_format.upper() == "HUDI":
+            if (
+                time_travel_format is not None
+                and time_travel_format.upper() == "HUDI"
+                and self._features
+            ):
                 # hudi precombine key is always a single feature
                 self._hudi_precombine_key = [
                     feat.name
