@@ -64,6 +64,7 @@ class TrainingDataset:
         querydto=None,
         label=None,
         transformation_functions=None,
+        train_split=None,
     ):
         self._id = id
         self._name = name
@@ -79,7 +80,9 @@ class TrainingDataset:
         self._prepared_statement_engine = None
         self._prepared_statements = None
         self._serving_keys = None
+        self._pkname_by_serving_index = None
         self._transformation_functions = transformation_functions
+        self._train_split = train_split
 
         self._training_dataset_api = training_dataset_api.TrainingDatasetApi(
             featurestore_id
@@ -142,6 +145,7 @@ class TrainingDataset:
         This method materializes the training dataset either from a Feature Store
         `Query`, a Spark or Pandas `DataFrame`, a Spark RDD, two-dimensional Python
         lists or Numpy ndarrays.
+        From v2.5 onward, filters are saved along with the `Query`.
 
         # Arguments
             features: Feature data to be materialized.
@@ -451,6 +455,7 @@ class TrainingDataset:
             "seed": self._seed,
             "queryDTO": self._querydto.to_dict() if self._querydto else None,
             "statisticsConfig": self._statistics_config,
+            "trainSplit": self._train_split,
         }
 
     @property
@@ -623,7 +628,7 @@ class TrainingDataset:
     @property
     def query(self):
         """Query to generate this training dataset from online feature store."""
-        return self._training_dataset_engine.query(self, True, True)
+        return self._training_dataset_engine.query(self, True, True, False)
 
     def get_query(self, online: bool = True, with_label: bool = False):
         """Returns the query used to generate this training dataset
@@ -639,21 +644,26 @@ class TrainingDataset:
             `str`. Query string for the chosen storage used to generate this training
                 dataset.
         """
-        return self._training_dataset_engine.query(self, online, with_label)
+        return self._training_dataset_engine.query(
+            self, online, with_label, engine.get_type() == "hive"
+        )
 
-    def init_prepared_statement(self, external: Optional[bool] = False):
+    def init_prepared_statement(
+        self, batch: Optional[bool] = None, external: Optional[bool] = False
+    ):
         """Initialise and cache parametrized prepared statement to
            retrieve feature vector from online feature store.
 
         # Arguments
+            batch: boolean, optional. If set to True, prepared statements will be
+                initialised for retrieving serving vectors as a batch.
             external: boolean, optional. If set to True, the connection to the
                 online feature store is established using the same host as
                 for the `host` parameter in the [`hsfs.connection()`](project.md#connection) method.
                 If set to False, the online feature store storage connector is used
                 which relies on the private IP.
         """
-        if self.prepared_statements is None:
-            self._training_dataset_engine.init_prepared_statement(self, external)
+        self._training_dataset_engine.init_prepared_statement(self, batch, external)
 
     def get_serving_vector(
         self, entry: Dict[str, Any], external: Optional[bool] = False
@@ -674,6 +684,25 @@ class TrainingDataset:
         """
         return self._training_dataset_engine.get_serving_vector(self, entry, external)
 
+    def get_serving_vectors(
+        self, entry: Dict[str, List[Any]], external: Optional[bool] = False
+    ):
+        """Returns assembled serving vectors in batches from online feature store.
+
+        # Arguments
+            entry: dict of feature group primary key names as keys and value as list of primary keys provided by
+                serving application.
+            external: boolean, optional. If set to True, the connection to the
+                online feature store is established using the same host as
+                for the `host` parameter in the [`hsfs.connection()`](project.md#connection) method.
+                If set to False, the online feature store storage connector is used
+                which relies on the private IP.
+        # Returns
+            `List[list]` List of lists of feature values related to provided primary keys, ordered according to
+            positions of this features in training dataset query.
+        """
+        return self._training_dataset_engine.get_serving_vectors(self, entry, external)
+
     @property
     def label(self):
         """The label/prediction feature of the training dataset.
@@ -719,6 +748,15 @@ class TrainingDataset:
     def serving_keys(self, serving_vector_keys):
         self._serving_keys = serving_vector_keys
 
+    @property
+    def train_split(self):
+        """Set name of training dataset split that is used for training."""
+        return self._train_split
+
+    @train_split.setter
+    def train_split(self, train_split):
+        self._train_split = train_split
+
     @property
     def transformation_functions(self):
         """Set transformation functions."""
